@@ -792,6 +792,16 @@ class Instance(JavaObject):
                 weight, javabridge.get_env().make_double_array(vals),
                 javabridge.get_env().make_int_array(indices), max_values))
 
+    @classmethod
+    def missing_value(cls):
+        """
+        Returns the numeric value that represents a missing value in Weka (NaN).
+
+        :return: missing value
+        :rtype: float
+        """
+        return missing_value()
+
 
 class Attribute(JavaObject):
     """
@@ -1447,32 +1457,80 @@ class InstanceValueIterator(object):
             raise StopIteration()
 
 
-def create_instances_from_lists(x, y, name="data"):
+def create_instances_from_lists(x, y=None, name="data"):
     """
-    Allows the generation of an Instances object from a list of lists for X and a list for Y.
+    Allows the generation of an Instances object from a list of lists for X and a list for Y (optional).
     All data must be numerical. Attributes can be converted to nominal with the
     weka.filters.unsupervised.attribute.NumericToNominal filter.
 
     :param x: the input variables (row wise)
     :type x: list of list
-    :param y: the output variable
+    :param y: the output variable (optional)
     :type y: list
     :param name: the name of the dataset
     :type name: str
     :return: the generated dataset
     :rtype: Instances
     """
-    if len(x) != len(y):
-        raise Exception("Dimensions of x and y differ: " + str(len(x)) + " != " + str(len(y)))
+    if y is not None:
+        if len(x) != len(y):
+            raise Exception("Dimensions of x and y differ: " + str(len(x)) + " != " + str(len(y)))
     # create header
     atts = []
     for i in xrange(len(x[0])):
         atts.append(Attribute.create_numeric("x" + str(i+1)))
-    atts.append(Attribute.create_numeric("y"))
-    result = Instances.create_instances(name, atts, len(y))
+    if y is not None:
+        atts.append(Attribute.create_numeric("y"))
+    result = Instances.create_instances(name, atts, len(x))
     # add data
     for i in xrange(len(x)):
         values = x[i][:]
-        values.append(y[i])
+        if y is not None:
+            values.append(y[i])
         result.add_instance(Instance.create_instance(values))
     return result
+
+
+def create_instances_from_matrices(x, y=None, name="data"):
+    """
+    Allows the generation of an Instances object from a 2-dimensional matrix for X and a
+    1-dimensional matrix for Y (optional).
+    All data must be numerical. Attributes can be converted to nominal with the
+    weka.filters.unsupervised.attribute.NumericToNominal filter.
+
+    :param x: the input variables
+    :type x: ndarray
+    :param y: the output variable (optional)
+    :type y: ndarray
+    :param name: the name of the dataset
+    :type name: str
+    :return: the generated dataset
+    :rtype: Instances
+    """
+    if y is not None:
+        if len(x) != len(y):
+            raise Exception("Dimensions of x and y differ: " + str(len(x)) + " != " + str(len(y)))
+    # create header
+    atts = []
+    for i in xrange(len(x[0])):
+        atts.append(Attribute.create_numeric("x" + str(i+1)))
+    if y is not None:
+        atts.append(Attribute.create_numeric("y"))
+    result = Instances.create_instances(name, atts, len(x))
+    # add data
+    for i in xrange(len(x)):
+        values = list(x[i])
+        if y is not None:
+            values.append(y[i])
+        result.add_instance(Instance.create_instance(values))
+    return result
+
+
+def missing_value():
+    """
+    Returns the value that represents missing values in Weka (NaN).
+
+    :return: missing value
+    :rtype: float
+    """
+    return float("NaN")
